from typing import Literal

TextTransform = Literal[
    'uppercase',
    'lowercase',
    'capitalize',
    'normal-case',
]
